Flask-Useful
============

|PyPI| |LICENCE| |STARS|

|DOWNLOADS| |DOWNLOADS_M| |DOWNLOADS_W|

**Flask-Useful** - A set of useful tools for the Flask microframework.

Installation
------------

Install the latest stable version by running the command::

    pip install Flask-Useful


.. |PyPI| image:: https://img.shields.io/pypi/v/flask-useful.svg
   :target: https://pypi.org/project/flask-useful/
   :alt: Latest Version

.. |LICENCE| image:: https://img.shields.io/github/license/kyzima-spb/flask-useful.svg
   :target: https://github.com/kyzima-spb/flask-useful/blob/master/LICENSE
   :alt: MIT

.. |STARS| image:: https://img.shields.io/github/stars/kyzima-spb/flask-useful.svg
   :target: https://github.com/kyzima-spb/flask-useful/stargazers
   :alt: GitHub stars

.. |DOWNLOADS| image:: https://pepy.tech/badge/flask-useful
   :target: https://pepy.tech/project/flask-useful

.. |DOWNLOADS_M| image:: https://pepy.tech/badge/flask-useful/month
   :target: https://pepy.tech/project/flask-useful)

.. |DOWNLOADS_W| image:: https://pepy.tech/badge/flask-useful/week
   :target: https://pepy.tech/project/flask-useful)
